@@ -7,7 +7,7 @@
 
  Module to provide class hierachy to simplify access to the BloxOne APIs
 
- Date Last Updated: 20200820
+ Date Last Updated: 20200907
 
  Todo:
 
@@ -39,17 +39,17 @@
 
 ------------------------------------------------------------------------
 '''
-__version__ = '0.5.7'
-__author__ = 'Chris Marrison'
-__author_email__ = 'chris@infoblox.com'
-
 import logging
 import configparser
 import requests
 import json
 
 # ** Global Vars **
-cspurl = "https://csp.infoblox.com/api"
+__version__ = '0.6.1'
+__author__ = 'Chris Marrison'
+__email__ = 'chris@infoblox.com'
+__doc__ = 'https://python-bloxone.readthedocs.io/en/latest/'
+__license__ = 'BSD'
 
 
 # ** Facilitate ini file for basic configuration including API Key
@@ -62,7 +62,7 @@ def read_b1_ini(ini_filename):
         ini_filename (str): name of inifile
 
     Returns:
-        config (dict): Dictionary of BloxOne configuration elements
+        config :(dict): Dictionary of BloxOne configuration elements
 
     '''
     # Local Variables
@@ -128,7 +128,8 @@ class b1:
         self.tddfp_url = self.base_url + '/api/atcdfp/' + self.cfg['api_version']
         self.tdlad_url = self.base_url + '/api/atclad/' + self.cfg['api_version']
         self.tide_url = self.base_url + '/tide/api' 
-        self.dossier_url = self.base_url + '/dossier/api' # Placeholder
+        self.dossier_url = self.base_url + '/tide/api/services/intel/lookup'
+        self.threat_enrichment_url = self.base_url + '/tide/threat-enrichment'
 
         # List of successful return codes
         self.return_codes_ok = [200, 201, 204]
@@ -167,12 +168,16 @@ class b1:
         return response
 
 
-    def _apipost(self, url, body):    
-     # Call BloxOne API
+    def _apipost(self, url, body, headers=""):    
+        # Set headers
+        if not headers:
+            headers = self.headers
+     
+        # Call BloxOne API
         try:
             response = requests.request("POST",
                                         url,
-                                        headers=self.headers,
+                                        headers=headers,
                                         data=body)
         # Catch exceptions
         except requests.exceptions.RequestException as e:
@@ -248,7 +253,7 @@ class b1:
             nextip (bool): use nextavailableip
 
         Returns:
-            url (str): Updated url
+            string : Updated url
         '''
         # Check for id and next available IP
         if id:
@@ -278,7 +283,7 @@ class b1platform(b1):
             action (str):   Optional object action, e.g. "nextavailableip"
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
 
         # Build url
@@ -301,7 +306,7 @@ class b1platform(b1):
             body (str):     JSON formatted data payload
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
         # Build url
         url = self.host_url + objpath
@@ -322,7 +327,7 @@ class b1platform(b1):
             id (str):       Object id to delete
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
         # Build url
         url = self.host_url + objpath
@@ -344,7 +349,7 @@ class b1platform(b1):
             body (str):     JSON formatted data payload
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
         # Build url
         url = self.host_url + objpath
@@ -396,7 +401,7 @@ class b1platform(b1):
             **params (dict): Generic API parameters
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
 
         # Call BloxOne API
@@ -416,7 +421,7 @@ class b1platform(b1):
             tagvalue (str): Value to associate
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
         # tags = self.get_tags('/on_prem_hosts', id=id)
         response = self.get('/on_prem_hosts', id=id, _fields="display_name,tags")
@@ -444,7 +449,7 @@ class b1platform(b1):
             tagname (str): Name of tag to add
 
         Returns:
-            response (obj): Requests response object
+            response object: Requests response object
         '''
         # tags = self.get_tags('/on_prem_hosts', id=id)
         response = self.get('/on_prem_hosts', id=id, _fields="display_name,tags")
@@ -459,4 +464,22 @@ class b1platform(b1):
                 # Update object
                 response = self.update('/on_prem_hosts', id=id, body=json.dumps(data))
 
-        return response
\ No newline at end of file
+        return response
+
+
+    def auditlog(self, **params):
+        '''
+        Get the audit log
+
+        Parameters:
+            **params (dict): Generic API parameters
+        Returns:
+            response object: Requests response object
+        '''
+        url = self.base_url + '/api/auditlog/' + self.api_version +'/logs'
+        url = self._add_params(url, **params)
+        logging.debug("URL: {}".format(url))
+
+        response = self._apiget(url)
+
+        return response
